summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAndrew Jeffery <andrew@aj.id.au>2018-08-08 17:25:47 +0930
committerAndrew Jeffery <andrew@aj.id.au>2018-09-05 17:44:24 +0930
commit9412f0597d8f43f74184eaf7733c3f3b666664d7 (patch)
treeaf544d8ae9577513530803bcebfedcb0ae55b808
parentd6a7426e3945feb265f029feb489cb5d2f571f90 (diff)
downloadphosphor-mboxbridge-9412f0597d8f43f74184eaf7733c3f3b666664d7.tar.gz
phosphor-mboxbridge-9412f0597d8f43f74184eaf7733c3f3b666664d7.zip
windows: Rename find_oldest_window to windows_find_oldest
Change-Id: I7b76fc57b6b1002c195af86167ae4fa6fd99489c Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
-rw-r--r--windows.c6
-rw-r--r--windows.h2
2 files changed, 4 insertions, 4 deletions
diff --git a/windows.h b/windows.h
index 943ea9b..3cb2a52 100644
--- a/windows.h
+++ b/windows.h
@@ -25,7 +25,7 @@ void windows_close_current(struct mbox_context *context, bool set_bmc_event,
uint8_t flags);
void window_reset(struct mbox_context *context, struct window_context *window);
void windows_reset_all(struct mbox_context *context, bool set_bmc_event);
-struct window_context *find_oldest_window(struct mbox_context *context);
+struct window_context *windows_find_oldest(struct mbox_context *context);
struct window_context *find_largest_window(struct mbox_context *context);
struct window_context *search_windows(struct mbox_context *context,
uint32_t offset, bool exact);
OpenPOWER on IntegriCloud
diff --git a/windows.c b/windows.c
index 3759bb3..37fceb1 100644
--- a/windows.c
+++ b/windows.c
@@ -444,12 +444,12 @@ void windows_reset_all(struct mbox_context *context, bool set_bmc_event)
}
/*
* find_oldest_window() - Find the oldest (Least Recently Used) window
* @context: The mbox context pointer
*
* Return: Pointer to the least recently used window
*/
-struct window_context *find_oldest_window(struct mbox_context *context)
+struct window_context *windows_find_oldest(struct mbox_context *context)
{
struct window_context *oldest = NULL, *cur;
uint32_t min_age = context->windows.max_age + 1;
@@ -567,7 +567,7 @@ int create_map_window(struct mbox_context *context,
/* No uninitialised window found, we need to choose one to "evict" */
if (!cur) {
MSG_DBG("No uninitialised window, evicting one\n");
- cur = find_oldest_window(context);
+ cur = windows_find_oldest(context);
window_reset(context, cur);
}
@@ -444,12 +444,12 @@ void windows_reset_all(struct mbox_context *context, bool set_bmc_event)
}
/*
- * find_oldest_window() - Find the oldest (Least Recently Used) window
+ * windows_find_oldest() - Find the oldest (Least Recently Used) window
* @context: The mbox context pointer
*